library(tidyverse)
library(tidymodels)
library(readxl)

# Part 1:
DataCl= read_excel("WageDataModifRTalk.xlsx", 
                   sheet = "DataClean") 


MeanWage=mean()

## Part 2 ###

# Use tidyverse to create wage data Data Frame (tibble) 

# 1) with only the Sex and Wage variable
# 2) women only and 
# 3) convert 1976 wages to purchasing power 2021 Data Engeneering
# Select, filter, and mutate



DataWageAndSexOnly=select() # Select Sex and Wage76=Wage 

DataWageFemale=filter() # filter for Female

DataFemWith2021Wages=mutate() # Wage21=Wage76*3.8
rm(DataWageAndSexOnly,DataWageFemale,DataFemWith2021Wages)

# Piping
DataFemaleFinal=DataCl %>% select() %>% filter() %>% mutate()

DataMaleFinal=
# Female Avg. Wage in 2021 Prices
mean(DataFemaleFinal$Wage21)

# Male Avg. Wage in 2021 Prices
mean(DataMaleFinal$Wage21)

# Simple Analysis
# Compare Wages ANOVA
t.test() #compare wages from DataFemaleFinal and DataMaleFinal

ModelLmSimple=lm(Wage~Educ+Exper+Tenure+Sex, data = DataCl)
summary(ModelLmSimple)

rm(MeanWage, DataFemaleFinal,DataMaleFinal, ModelLmSimple)
###################

## PART 3a ###
# Data Engineering and Modeling with Tidymodels - Simple Recipes

set.seed(321)
Split85Cl=initial_split(DataCl, prop = 0.85)

DataTrainCl=training(Split85Cl)
DataTestCl=testing(Split85Cl)

# For a list of all steps_* see: https://www.tidymodels.org/find/recipes/

RecipeCl=DataTrainCl %>% 
  recipe(Wage~Educ+Exper+Tenure+Sex) %>% 
  step_meanimpute(Educ,Tenure) %>% 
  step_modeimpute(Sex) %>% 
  step_dummy(all_nominal()) %>% 
  prep()



DataTemp=bake(RecipeCl, new_data=DataTrainCl)     

#### Part 3b: 
# Data Engineering and Modeling with Tidymodels - Workflow (advanced)


rm(DataTemp)

# For all models see: https://www.tidymodels.org/find/parsnip/

ModelLmCl=
  linear_reg() %>%
  set_engine('lm')%>%
  set_mode('regression')

WorkFlowCl=workflow() %>%
  add_recipe(RecipeCl) %>% 
  add_model(ModelLmCl) %>% 
  fit(DataTrainCl)

summary(WorkFlowCl$fit$fit$fit)


MetricsLmTrain=WorkFlowCl %>% predict(DataTrainCl) %>%
  bind_cols(DataTrainCl)%>% 
  metrics(truth=Wage, estimate=.pred)

MetricsLmTest=WorkFlowCl %>% predict(DataTestCl) %>%
  bind_cols(DataTestCl)%>% 
  metrics(truth=Wage, estimate=.pred)

# ****** Random Forest Model ************
set.seed(321)
